@@ -75,18 +75,6 @@ clearlooks_draw_gummy_gradient (cairo_t          *cr,
 	cairo_pattern_destroy (pt);
 }
 
-static void
-clearlooks_set_mixed_color (cairo_t          *cr,
-                            const CairoColor *color1,
-                            const CairoColor *color2,
-                            gdouble mix_factor)
-{
-	CairoColor composite;
-
-	ge_mix_color (color1, color2, mix_factor, &composite);
-	ge_cairo_set_color (cr, &composite);
-}
-
 static void
 clearlooks_gummy_draw_highlight_and_shade (cairo_t                *cr,
                                            const CairoColor       *bg_color,
@@ -286,8 +274,10 @@ clearlooks_gummy_draw_entry (cairo_t                *cr,
 	/* Draw the inner shadow */
 	if (params->focus)
 	{
-		/* XXX Fix this with focus->has_color */
-		clearlooks_set_mixed_color (cr, base, &colors->spot[1], 0.5);
+		CairoColor focus_shadow;
+		ge_shade_color (&border, 1.61, &focus_shadow);
+		
+		clearlooks_set_mixed_color (cr, base, &focus_shadow, 0.5);
 		ge_cairo_inner_rounded_rectangle (cr, 2, 2, width-4, height-4, MAX(0, radius-1), params->corners);
 		cairo_stroke (cr);
 	}
@@ -422,7 +412,7 @@ clearlooks_gummy_draw_progressbar_fill (cairo_t                     *cr,
 	cairo_pattern_destroy (pattern);
 
 	/* Draw the strokes */
-	while (tile_pos <= width+x_step)
+	while (stroke_width > 0 && tile_pos <= width+x_step)
 	{
 		cairo_move_to (cr, stroke_width/2-x_step, 0);
 		cairo_line_to (cr, stroke_width-x_step,   0);
@@ -989,6 +979,16 @@ clearlooks_gummy_draw_scrollbar_stepper (cairo_t                          *cr,
 			corners = CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMLEFT;
 		else if (stepper->stepper == CL_STEPPER_D)
 			corners = CR_CORNER_TOPRIGHT | CR_CORNER_BOTTOMRIGHT;
+
+		if (stepper->stepper == CL_STEPPER_B)
+		{
+			x -= 1;
+			width += 1;
+		}
+		else if (stepper->stepper == CL_STEPPER_C)
+		{
+			width += 1;
+		}
 	}
 	else
 	{
@@ -996,6 +996,16 @@ clearlooks_gummy_draw_scrollbar_stepper (cairo_t                          *cr,
 			corners = CR_CORNER_TOPLEFT | CR_CORNER_TOPRIGHT;
 		else if (stepper->stepper == CL_STEPPER_D)
 			corners = CR_CORNER_BOTTOMLEFT | CR_CORNER_BOTTOMRIGHT;
+
+		if (stepper->stepper == CL_STEPPER_B)
+		{
+			y -= 1;
+			height += 1;
+		}
+		else if (stepper->stepper == CL_STEPPER_C)
+		{
+			height += 1;
+		}
 	}
 
 	cairo_translate (cr, x, y);
